@@ -2,13 +2,15 @@
 // Distributed under the MIT license, see the LICENSE file for details.
 
 #include "base64.h"
+#include <cassert>
 
 namespace chromaprint {
 
 void Base64Encode(const std::string &src, std::string &dest)
 {
 	dest.resize(GetBase64EncodedSize(src.size()));
-	Base64Encode(src.cbegin(), src.cend(), dest.begin());
+	const auto end = Base64Encode(src.cbegin(), src.cend(), dest.begin());
+	assert(dest.end() == end);
 }
 
 std::string Base64Encode(const std::string &src)
@@ -21,7 +23,8 @@ std::string Base64Encode(const std::string &src)
 void Base64Decode(const std::string &src, std::string &dest)
 {
 	dest.resize(GetBase64DecodedSize(src.size()));
-	Base64Decode(src.cbegin(), src.cend(), dest.begin());
+	const auto end = Base64Decode(src.cbegin(), src.cend(), dest.begin());
+	assert(dest.end() == end);
 }
 
 std::string Base64Decode(const std::string &src)
